Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetValidMethods ¶
func GetValidMethods() []string
GetValidMethods returns allowed superset of the HTTP methods
func ValidateMethod ¶
ValidateMethod validates that the methods is in the the right set
Types ¶
type JSONBinding ¶
type JSONBinding struct{}
JSONBinding that reprents the access to the underlying database
type Request ¶
Request generically represents inputs to the service
func NewRequest ¶
NewRequest Creates a new generic request
type Response ¶
type Response struct {
Headers map[string]string
Code int `json:"code"`
Body interface{} `json:"body,omitempty"`
}
Response generically represents outputs from the service
Click to show internal directories.
Click to hide internal directories.